#ifndef NT2_INCLUDE_CONSTANTS_INF_HPP_INCLUDED
#define NT2_INCLUDE_CONSTANTS_INF_HPP_INCLUDED

#include <nt2/constant/include/constants/inf.hpp>

#endif
